==> eidolon_ai_sdk-0.1.53-py3-none-any.whl: eidolon_ai_sdk/agent/tot_agent/checker.py <==
from typing import List

from jinja2 import StrictUndefined, Environment
from pydantic import Field, BaseModel

from eidolon_ai_sdk.cpu.apu import APU
from eidolon_ai_sdk.cpu.agent_io import UserTextAPUMessage
from eidolon_ai_sdk.agent.tot_agent.prompts import CHECKER_PROMPT
from eidolon_ai_sdk.agent.tot_agent.thought import ThoughtValidity
from eidolon_ai_sdk.system.reference_model import Specable


class TotCheckerConfig(BaseModel):
    prompt: str = CHECKER_PROMPT
    examples: str = ""


class ToTChecker(Specable[TotCheckerConfig]):
    spec: TotCheckerConfig
    cpu: APU

    def __init__(self, cpu, spec):
        super().__init__(spec)
        self.cpu = cpu
        self.spec = spec

    """
    Tree of Thought (ToT) checker.

    This is an abstract ToT checker that can be implemented by the user. You
    can implement a simple rule-based checker or a more sophisticated
    neural network based classifier.
    """

    async def evaluate(
        self,
        process_id: str,
        problem_description: str,
        thoughts: List[str] = Field(default_factory=list),
    ) -> ThoughtValidity:
        """
        Evaluate the response to the problem description and return the solution type.
        """

        checker_prompt = (
            Environment(undefined=StrictUndefined)
            .from_string(self.spec.prompt)
            .render(
                problem=problem_description,
                thoughts=thoughts,
                examples=self.spec.examples,
            )
        )

        thread = await self.cpu.new_thread(process_id)
        resp = await thread.run_request(
            prompts=[UserTextAPUMessage(prompt=checker_prompt)],
            output_format=ThoughtValidity.model_json_schema(),
        )

        return ThoughtValidity.model_validate(resp)

==> eidolon_ai_sdk-0.1.89-py3-none-any.whl: eidolon_ai_sdk/agent/tot_agent/checker.py <==
from typing import List

from jinja2 import StrictUndefined, Environment
from pydantic import Field, BaseModel

from eidolon_ai_sdk.apu.apu import APU
from eidolon_ai_sdk.apu.agent_io import UserTextAPUMessage
from eidolon_ai_sdk.agent.tot_agent.prompts import CHECKER_PROMPT
from eidolon_ai_sdk.agent.tot_agent.thought import ThoughtValidity
from eidolon_ai_sdk.system.reference_model import Specable


class TotCheckerConfig(BaseModel):
    prompt: str = CHECKER_PROMPT
    examples: str = ""


class ToTChecker(Specable[TotCheckerConfig]):
    spec: TotCheckerConfig
    apu: APU

    def __init__(self, apu, spec):
        super().__init__(spec)
        self.apu = apu
        self.spec = spec

    """
    Tree of Thought (ToT) checker.

    This is an abstract ToT checker that can be implemented by the user. You
    can implement a simple rule-based checker or a more sophisticated
    neural network based classifier.
    """

    async def evaluate(
        self,
        process_id: str,
        problem_description: str,
        thoughts: List[str] = Field(default_factory=list),
    ) -> ThoughtValidity:
        """
        Evaluate the response to the problem description and return the solution type.
        """

        checker_prompt = (
            Environment(undefined=StrictUndefined)
            .from_string(self.spec.prompt)
            .render(
                problem=problem_description,
                thoughts=thoughts,
                examples=self.spec.examples,
            )
        )

        thread = await self.apu.new_thread(process_id)
        resp = await thread.run_request(
            prompts=[UserTextAPUMessage(prompt=checker_prompt)],
            output_format=ThoughtValidity.model_json_schema(),
        )

        return ThoughtValidity.model_validate(resp)
